{
  description = "Nixos config flake";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixos-24.11";

    home-manager.url = "github:nix-community/home-manager/release-24.11";

    sops-nix.url = "github:Mic92/sops-nix";

    musnix.url = "github:musnix/musnix";
  };

  outputs = {
    nixpkgs,
    home-manager,
    sops-nix,
    musnix,
    ...
  } @ inputs: let
    system = "x86_64-linux";
    pkgs = import nixpkgs {
      inherit system;
      config = {
        allowUnfreePredicate = pkg:
          builtins.elem (nixpkgs.lib.getName pkg) [
            "discord"
            "samsung-UnifiedLinuxDriver"
            "steam"
            "steam-unwrapped"
          ];
      };
    };
  in {
    nixosConfigurations."MaxNixosLaptop" = nixpkgs.lib.nixosSystem {
      specialArgs = {
        inherit inputs;
        inherit pkgs;
      };
      system = "x86_64-linux";
      modules = [
        ./hosts/MaxNixosLaptop/configuration.nix
        sops-nix.nixosModules.sops
        home-manager.nixosModules.default
        {
          home-manager.useGlobalPkgs = true;
          home-manager.useUserPackages = true;
        }
        musnix.nixosModules.musnix
      ];
    };
  };
}
